@@ -36,67 +36,59 @@ pub fn get_nodes(content_type: &ContentType) -> Vec<Node> {
         ContentType::Article => {
             vec![
                 Node {
-                    nid: 10,
+                    nid: 11,
                     url_en: "/en/articles/give-it-a-go-and-grow-your-own-herbs",
                     url_es: "/es/articles/prueba-y-cultiva-tus-propias-hierbas",
                     title_en: "Give it a go and grow your own herbs",
                     title_es: "Prueba y cultiva tus propias hierbas",
                 },
                 Node {
-                    nid: 11,
+                    nid: 12,
                     url_en: "/en/articles/dairy-free-and-delicious-milk-chocolate",
                     url_es: "/es/articles/delicioso-chocolate-sin-lactosa",
                     title_en: "Dairy-free and delicious milk chocolate",
                     title_es: "Delicioso chocolate sin lactosa",
                 },
                 Node {
-                    nid: 12,
+                    nid: 13,
                     url_en: "/en/articles/the-real-deal-for-supermarket-savvy-shopping",
                     url_es: "/es/articles/el-verdadeo-negocio-para-comprar-en-el-supermercado",
                     title_en: "The real deal for supermarket savvy shopping",
                     title_es: "El verdadero negocio para comprar en el supermercado",
                 },
                 Node {
-                    nid: 13,
+                    nid: 14,
                     url_en: "/en/articles/the-umami-guide-to-our-favourite-mushrooms",
                     url_es: "/es/articles/guia-umami-de-nuestras-setas-preferidas",
                     title_en: "The Umami guide to our favorite mushrooms",
                     title_es: "Guía Umami de nuestras setas preferidas",
                 },
                 Node {
-                    nid: 14,
+                    nid: 15,
                     url_en: "/en/articles/lets-hear-it-for-carrots",
                     url_es: "/es/articles/un-aplauso-para-las-zanahorias",
                     title_en: "Let&#039;s hear it for carrots",
                     title_es: "Un aplauso para las zanahorias",
                 },
                 Node {
-                    nid: 15,
+                    nid: 16,
                     url_en: "/en/articles/baking-mishaps-our-troubleshooting-tips",
-                    url_es:
-                        "/es/articles/percances-al-hornear-nuestros-consejos-para-solucionar-problemas",
+                    url_es: "es/articles/percances-al-hornear-nuestros-consejos-para-solucionar-problemas",
                     title_en: "Baking mishaps - our troubleshooting tips",
                     title_es: "Percances al hornear - nuestros consejos para solucionar los problemas",
                 },
                 Node {
-                    nid: 16,
+                    nid: 17,
                     url_en: "/en/articles/skip-the-spirits-with-delicious-mocktails",
                     url_es: "/es/articles/salta-los-espiritus-con-deliciosos-cocteles-sin-alcohol",
                     title_en: "Skip the spirits with delicious mocktails",
                     title_es: "Salta los espíritus con deliciosos cócteles sin alcohol",
                 },
-                Node {
-                    nid: 17,
-                    url_en: "/en/articles/give-your-oatmeal-the-ultimate-makeover",
-                    url_es: "/es/articles/dale-a-tu-avena-el-cambio-de-imagen-definitivo",
-                    title_en: "Give your oatmeal the ultimate makeover",
-                    title_es: "Dale a tu avena el cambio de imagen definitivo",
-                },
             ]
         }
         ContentType::BasicPage => {
             vec![Node {
-                nid: 18,
+                nid: 19,
                 url_en: "/en/about-umami",
                 url_es: "/es/acerca-de-umami",
                 title_en: "About Umami",
@@ -168,6 +160,13 @@ pub fn get_nodes(content_type: &ContentType) -> Vec<Node> {
                     title_en: "Fiery chili sauce",
                     title_es: "Salsa de chile ardiente",
                 },
+                Node {
+                    nid: 10,
+                    url_en: "/en/recipes/borscht-with-pork-ribs",
+                    url_es: "/es/recipes/borscht-con-costillas-de-cerdo",
+                    title_en: "Borscht with pork ribs",
+                    title_es: "Borscht con costillas de cerdo",
+                },
             ]
         }
     }
@@ -453,7 +452,7 @@ pub async fn validate_and_load_static_assets(
     user: &mut GooseUser,
     mut goose: GooseResponse,
     title: &str,
-) -> GooseTaskResult {
+) -> TransactionResult {
     match goose.response {
         Ok(response) => {
             // Copy the headers so we have them for logging if there are errors.
@@ -502,7 +501,7 @@ pub fn get_form_value(html: &str, name: &str) -> Option<String> {
 
 /// Anonymously load the contact form and POST feedback. The english boolean flag indicates
 /// whether to load the English form or the Spanish form.
-pub async fn anonymous_contact_form(user: &mut GooseUser, english: bool) -> GooseTaskResult {
+pub async fn anonymous_contact_form(user: &mut GooseUser, english: bool) -> TransactionResult {
     let contact_form_url = if english {
         "/en/contact"
     } else {
@@ -636,7 +635,7 @@ pub async fn anonymous_contact_form(user: &mut GooseUser, english: bool) -> Goos
 
 /// Load the search page and perform a search using one word from one of the node titles
 /// on the site.
-pub async fn search(user: &mut GooseUser, english: bool) -> GooseTaskResult {
+pub async fn search(user: &mut GooseUser, english: bool) -> TransactionResult {
     let search_form_url = if english {
         "/en/search/node"
     } else {
