@@ -5,6 +5,7 @@
 
 use crate::config::GooseConfiguration;
 use crate::metrics::GooseMetrics;
+use crate::test_plan::{TestPlan, TestPlanHistory, TestPlanStepAction};
 use crate::util;
 use crate::{AttackPhase, GooseAttack, GooseAttackRunState, GooseError};
 
@@ -1149,10 +1150,12 @@ impl GooseAttack {
                         GooseControllerCommand::Start => {
                             // We can only start an idle load test.
                             if self.attack_phase == AttackPhase::Idle {
+                                self.test_plan = TestPlan::build(&self.configuration);
                                 if self.prepare_load_test().is_ok() {
+                                    // Rebuild test plan in case any parameters have been changed.
                                     self.set_attack_phase(
                                         goose_attack_run_state,
-                                        AttackPhase::Starting,
+                                        AttackPhase::Increase,
                                     );
                                     self.reply_to_controller(
                                         message,
@@ -1160,6 +1163,10 @@ impl GooseAttack {
                                     );
                                     // Reset the run state when starting a new load test.
                                     self.reset_run_state(goose_attack_run_state).await?;
+                                    self.metrics.history.push(TestPlanHistory::step(
+                                        TestPlanStepAction::Increasing,
+                                        0,
+                                    ));
                                 } else {
                                     // Do not move to Starting phase if unable to prepare load test.
                                     self.reply_to_controller(
@@ -1177,12 +1184,16 @@ impl GooseAttack {
                         // Stop the load test, and acknowledge command.
                         GooseControllerCommand::Stop => {
                             // We can only stop a starting or running load test.
-                            if [AttackPhase::Starting, AttackPhase::Running]
+                            if [AttackPhase::Increase, AttackPhase::Maintain]
                                 .contains(&self.attack_phase)
                             {
+                                self.metrics.history.push(TestPlanHistory::step(
+                                    TestPlanStepAction::Decreasing,
+                                    goose_attack_run_state.active_users,
+                                ));
                                 self.set_attack_phase(
                                     goose_attack_run_state,
-                                    AttackPhase::Stopping,
+                                    AttackPhase::Decrease,
                                 );
                                 // Don't shutdown when load test is stopped by controller, remain idle instead.
                                 goose_attack_run_state.shutdown_after_stop = false;
@@ -1204,11 +1215,15 @@ impl GooseAttack {
                             // If load test is Idle, there are no metrics to display.
                             if self.attack_phase == AttackPhase::Idle {
                                 self.metrics.display_metrics = false;
+                                self.set_attack_phase(
+                                    goose_attack_run_state,
+                                    AttackPhase::Decrease,
+                                );
+                            } else {
+                                self.cancel_attack(goose_attack_run_state).await?;
                             }
                             // Shutdown after stopping.
                             goose_attack_run_state.shutdown_after_stop = true;
-                            // Properly stop any running GooseAttack first.
-                            self.set_attack_phase(goose_attack_run_state, AttackPhase::Stopping);
                             // Confirm shut down to Controller.
                             self.reply_to_controller(
                                 message,
@@ -1306,7 +1321,6 @@ impl GooseAttack {
                                     self.configuration.run_time, run_time
                                 );
                                 self.configuration.run_time = run_time.clone();
-                                self.set_run_time()?;
                                 self.reply_to_controller(
                                     message,
                                     GooseControllerResponseMessage::Bool(true),
